SIDD creation helper functions (sarpy.io.product.sidd_structure_creation)
=========================================================================

.. automodule:: sarpy.io.product.sidd_structure_creation
    :members:
    :show-inheritance:
    :inherited-members:
